Welcome to DAX's documentation!
===============================

Contents:

.. toctree::
   :maxdepth: 3
   
   dax_installation
   dax_xnat_dataypes_install
   dax
   dax_manager
   contributors
   how_to_contribute
   faq